aboutsummaryrefslogtreecommitdiffstats
path: root/admin/cat_list.php
diff options
context:
space:
mode:
authorrub <rub@piwigo.org>2006-03-27 21:19:31 +0000
committerrub <rub@piwigo.org>2006-03-27 21:19:31 +0000
commit51a4de797c76dbda26741acacbda76013caa5f64 (patch)
treec1bb657262978e97aa19bb919275506d4a62029c /admin/cat_list.php
parentd63d25a61d2a7bf9272f78c73fbce6a7a3ff6eee (diff)
improvement issue 0000127&0000301:
o Fix Missing Adviser tests o Improve pwg_high , set to is_the_guest default value for enabled_high git-svn-id: http://piwigo.org/svn/trunk@1106 68402e56-0260-453c-a942-63ccdbb3a9ee
Diffstat (limited to 'admin/cat_list.php')
-rw-r--r--admin/cat_list.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/admin/cat_list.php b/admin/cat_list.php
index 510f5e284..7917b0a6a 100644
--- a/admin/cat_list.php
+++ b/admin/cat_list.php
@@ -78,8 +78,8 @@ $navigation.= '</a>';
// +-----------------------------------------------------------------------+
// | virtual categories management |
// +-----------------------------------------------------------------------+
-// request to delete a virtual category
-if (isset($_GET['delete']) and is_numeric($_GET['delete']))
+// request to delete a virtual category / not for an adviser
+if (isset($_GET['delete']) and is_numeric($_GET['delete']) and !is_adviser())
{
delete_categories(array($_GET['delete']));
array_push($page['infos'], $lang['cat_virtual_deleted']);